@@ -234,6 +234,9 @@ class Console(cmd.Cmd):
     def __printError(self, error):
         self.__cprinter.printError(error)
 
+    def __printWarning(self, warning):
+        self.__cprinter.printWarning(warning)
+
     def __printInfo(self, info):
         self.__cprinter.printInfo(cstr(info))
 
@@ -344,6 +347,8 @@ class Console(cmd.Cmd):
 
     def __generateChain(self, command):
         split = command.split(' ')
+        badbytes = self.__options.badbytes if self.__options.badbytes is not None else ''
+        value_with_badbytes = None
         try:
             old = self.__rs.options.color
             generator = split[0]
@@ -354,6 +359,9 @@ class Console(cmd.Cmd):
                         raise RopperError('Wrong option format. An option has to be set in the following format: option=value')
                     key, value = option.split('=')
                     options[key] = value
+                    badbytes_value = value.encode('ASCII')
+                    if any(badbyte in badbytes_value for badbyte in unhexlify(badbytes)):
+                        value_with_badbytes = value
             try:
 
                 self.__rs.options.color = False
@@ -366,6 +374,8 @@ class Console(cmd.Cmd):
 
                 self.__cprinter.println(chain)
                 # self.__printSeparator(before='\n\n')
+                if value_with_badbytes is not None:
+                    self.__printWarning("The input value {} contains badbytes!".format(value_with_badbytes))
                 self.__printInfo('rop chain generated!')
             except RopperError as e:
                 self.__rs.options.color = old
@@ -414,10 +424,70 @@ class Console(cmd.Cmd):
         else:
             self.__printInfo('No bytes to print')
 
+    def __printExamples(self):
+        self.__cprinter.println("""example uses:
+  [Generic]
+  {0}
+  {0} --file /bin/ls --console
+
+  [Information]
+  {0} --file /bin/ls --info
+  {0} --file /bin/ls --imports
+  {0} --file /bin/ls --sections
+  {0} --file /bin/ls --segments
+  {0} --file /bin/ls --set nx
+  {0} --file /bin/ls --unset nx
+  {0} --file /bin/ls --inst-count 5
+  {0} --file /bin/ls --search "sub eax" --badbytes 000a0d
+  {0} --file /bin/ls --search "sub eax" --detail
+  {0} --file /bin/ls --filter "sub eax"
+  {0} --file /bin/ls --opcode ffe4
+  {0} --file /bin/ls --opcode ffe?
+  {0} --file /bin/ls --opcode ??e4
+  {0} --file /bin/ls --detailed
+  {0} --file /bin/ls --ppr --nocolor
+  {0} --file /bin/ls --jmp esp,eax
+  {0} --file /bin/ls --type jop
+  {0} --file /bin/ls --chain execve
+  {0} --file /bin/ls --chain "execve cmd=/bin/sh" --badbytes 000a0d
+  {0} --file /bin/ls --chain "mprotect address=0xbfdff000 size=0x21000"
+  {0} --file /bin/ls /lib/libc.so.6 --console
+
+
+  [Assemble/Disassemble]
+  {0} --asm "jmp esp"
+  {0} --asm "mov eax, ecx; ret"
+  {0} --disasm ffe4
+
+  [Search]
+  {0} --file /bin/ls --search <searchstring>
+  ?\t\tany character
+  %\t\tany string
+
+  Example:
+
+  {0} --file /bin/ls --search "mov e?x"
+  0x000067f1: mov edx, dword ptr [ebp + 0x14]; mov dword ptr [esp], edx; call eax
+  0x00006d03: mov eax, esi; pop ebx; pop esi; pop edi; pop ebp; ret ;
+  0x00006d6f: mov ebx, esi; mov esi, dword ptr [esp + 0x18]; add esp, 0x1c; ret ;
+  0x000076f8: mov eax, dword ptr [eax]; mov byte ptr [eax + edx], 0; add esp, 0x18; pop ebx; ret ;
+
+  {0} --file /bin/ls --search "mov [%], edx"
+  0x000067ed: mov dword ptr [esp + 4], edx; mov edx, dword ptr [ebp + 0x14]; mov dword ptr [esp], edx; call eax;
+  0x00006f4e: mov dword ptr [ecx + 0x14], edx; add esp, 0x2c; pop ebx; pop esi; pop edi; pop ebp; ret ;
+  0x000084b8: mov dword ptr [eax], edx; ret ;
+  0x00008d9b: mov dword ptr [eax], edx; add esp, 0x18; pop ebx; ret ;
+
+  {0} --file /bin/ls --search "mov [%], edx" --quality 1
+  0x000084b8: mov dword ptr [eax], edx; ret ;
+  \n""".format(sys.argv[0]))
+
     @safe_cmd
     def __handleOptions(self, options):
         if options.sections:
             self.__printData('sections')
+        elif options.help_examples:
+            self.__printExamples();
         elif options.analyse:
             self.__loadGadgets()
             #self.do_analyse(options.analyse)
@@ -704,7 +774,7 @@ nx\t- Clears the NX-Flag (ELF|PE)"""
 
     def help_inst(self):
         self.__printHelpText(
-            'inst <instructions>', 'searchs instructions in executable sections')
+            'inst <instructions>', 'searches instructions in executable sections')
 
     @safe_cmd
     def do_opcode(self, text):
@@ -716,7 +786,7 @@ nx\t- Clears the NX-Flag (ELF|PE)"""
 
     def help_opcode(self):
         self.__printHelpText(
-            'opcode <opcode>', 'searchs opcode in executable sections\nExample:\nopcode ffe4\nopcode ff4?\nopcode ff??\n\nNot allowed:\nopcode ff?4')
+            'opcode <opcode>', 'searches opcode in executable sections\nExample:\nopcode ffe4\nopcode ff4?\nopcode ff??\n\nNot allowed:\nopcode ff?4')
 
     @safe_cmd
     def do_imagebase(self, text):
@@ -755,7 +825,7 @@ nx\t- Clears the NX-Flag (ELF|PE)"""
 
     def help_jmp(self):
         self.__printHelpText(
-            'jmp <reg[,reg...]>', 'searchs jmp reg instructions')
+            'jmp <reg[,reg...]>', 'searches jmp reg instructions')
 
     @safe_cmd
     def do_detailed(self, text):
@@ -1040,7 +1110,7 @@ nx\t- Clears the NX-Flag (ELF|PE)"""
         self.__cprinter.println()
 
     def help_semantic(self):
-        self.__printHelpText('semantic', 'Searchs gadgets\nsemantic <constraint>[; <constraint>][ !<stable reg>*]\n\nExample:\nsemantc eax==ebx; ecx==1 !edx !esi\n\nValid constraints:\nreg==reg\nreg==number\nreg==[reg]\nreg<+|-|*|/>=<reg|number|[reg]>')
+        self.__printHelpText('semantic', 'Searches gadgets\nsemantic <constraint>[; <constraint>][ !<stable reg>*]\n\nExample:\nsemantc eax==ebx; ecx==1 !edx !esi\n\nValid constraints:\nreg==reg\nreg==number\nreg==[reg]\nreg<+|-|*|/>=<reg|number|[reg]>')
 
     # @safe_cmd
     # def do_analyse(self, text):
@@ -1146,6 +1216,9 @@ class ConsolePrinter(object):
     def printError(self, message):
         self.printMessage(cstr('[ERROR]', Color.RED), message)
 
+    def printWarning(self, message):
+        self.printMessage(cstr('[WARNING]', Color.YELLOW), message)
+
     def printInfo(self, message):
         self.printMessage(cstr('[INFO]', Color.GREEN), message)
 
